==> owncloud-8.2.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/activity/l10n/lb.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Aktivitéit",
    "Personal activity feed for %s" : "Perséinlechen Aktivitéite-Feed fir %s",
    "Your feed URL is invalid" : "D'Feed-Adress ass ongëlteg",
    "Your settings have been updated." : "Deng Astellunge goufen aktualiséiert.",
    "Mail" : "Mail",
    "Stream" : "Floss",
    "This stream will show events like additions, changes & shares" : "Dëse Floss weist Evenementer wéi dobäigesaten, geännert a gedeelte Fichieren un",
    "There are no events for this filter" : "Et gi keng Evenenementer fir dëse Filter",
    "Activity notification" : "Aktivitéits-Notifikatiounen",
    "All Activities" : "All Aktivitéiten",
    "Activities by you" : "Aktivitéite vun dir",
    "Activities by others" : "Aktivitéite vun anere Leit",
    "\"remote user\"" : "\"Remote-Benotzer\"",
    "in %s" : "an %s",
    "%s and %s" : "%s an %s",
    ", " : ", ",
    "_%s and %n more_::_%s and %n more_" : ["%s an %n méi","%s an %n méi"],
    "Hello %s," : "Hallo %s,",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* an %n méi","* an %n méi"],
    "Notifications" : "Notifikatiounen",
    "List your own actions in the stream" : "Eegen Aktiounen am Floss oplëschten",
    "Notify about your own actions via email" : "Iwwer eegene Aktiounen iwwer E-Mail informéieren",
    "You need to set up your email address before you can receive notification emails." : "Du muss deng E-Mail-Adress konfiguréieren ier s de Notifikatiouns-Maile kanns emfänken.",
    "Send emails:" : "Emaile schécken:",
    "Hourly" : "All Stonn",
    "Daily" : "All Dag",
    "Weekly" : "All Woch",
    "Activity feed" : "Aktivitéits-Feed",
    "Enable RSS feed" : "RSS-Feed aktivéieren",
    "No activity yet" : "Bis elo keng Aktivitéit",
    "No more events to load" : "Keng weider Evenementer fir ze lueden",
    "Files" : "Fichieren"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/activity/l10n/lb.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Aktivitéit",
    "Personal activity feed for %s" : "Perséinlechen Aktivitéite-Feed fir %s",
    "Your feed URL is invalid" : "D'Feed-Adress ass ongëlteg",
    "Your settings have been updated." : "Deng Astellunge goufen aktualiséiert.",
    "Mail" : "Mail",
    "Stream" : "Floss",
    ", " : ", ",
    "This stream will show events like additions, changes & shares" : "Dëse Floss weist Evenementer wéi dobäigesaten, geännert a gedeelte Fichieren un",
    "There are no events for this filter" : "Et gi keng Evenenementer fir dëse Filter",
    "Today" : "Haut",
    "\"remote user\"" : "\"Remote-Benotzer\"",
    "Activity notification" : "Aktivitéits-Notifikatiounen",
    "All Activities" : "All Aktivitéiten",
    "Activities by you" : "Aktivitéite vun dir",
    "Activities by others" : "Aktivitéite vun anere Leit",
    "%s and %s" : "%s an %s",
    "Hello %s," : "Hallo %s,",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* an %n méi","* an %n méi"],
    "List your own actions in the stream" : "Eegen Aktiounen am Floss oplëschten",
    "Notify about your own actions via email" : "Iwwer eegene Aktiounen iwwer E-Mail informéieren",
    "You need to set up your email address before you can receive notification emails." : "Du muss deng E-Mail-Adress konfiguréieren ier s de Notifikatiouns-Maile kanns emfänken.",
    "Send emails:" : "Emaile schécken:",
    "Hourly" : "All Stonn",
    "Daily" : "All Dag",
    "Weekly" : "All Woch",
    "Activity feed" : "Aktivitéits-Feed",
    "Enable RSS feed" : "RSS-Feed aktivéieren",
    "No activity yet" : "Bis elo keng Aktivitéit",
    "No more events to load" : "Keng weider Evenementer fir ze lueden",
    "Files" : "Fichieren"
},
"nplurals=2; plural=(n != 1);");
